Learn R Programming

meteo (version 0.1-4)

dwdsp: Daily mean wind speed in m/s for July 2011

Description

Sample data set showing values of merged daily mean wind speed measurements from the Global Surface Summary of Day data (GSOD) with European Climate Assessment & Data set (ECA&D) for the month July 2011.

Usage

data(dwdsp)

Arguments

encoding

utf8

References

  • Global Surface Summary of the day data (ftp://ftp.ncdc.noaa.gov/pub/data/gsod/)
  • European Climate Assessment & Dataset (http://eca.knmi.nl/dailydata/predefinedseries.php)

Examples

Run this code
## load data 
data(dwdsp)
str(dwdsp)

Run the code above in your browser using DataLab