Learn R Programming

meteo (version 0.1-4)

tregcoef: Multiple linear regression coefficients for global daily air temperatures

Description

Multiple linear regression coefficients for mean, min., max. daily temperature on geometric temperature trend, MODIS LST, elevation, and topographic wetness index. The models is computed from GSOD and ECA&D and GHCN-Daily data.

Usage

data(tregcoef)

Arguments

encoding

utf8

References

Kilibarda, M., T. Hengl, G. B. M. Heuvelink, B. Graeler, E. Pebesma, M. Percec Tadic, and B. Bajat (2014), Spatio-temporal interpolation of daily temperatures for global land areas at 1 km resolution, J. Geophys. Res. Atmos., 119, 2294-2313, doi:10.1002/2013JD020803.

Examples

Run this code
data(tregcoef)
tregcoef[[1]] # model for mean daily temp.

Run the code above in your browser using DataLab